###############################################################################
###############################################################################
##
##  Copyright (c) 2013-2017, Cisco Systems, Inc. All rights reserved.
##
###############################################################################
###############################################################################

%define package_name cisco-enic-usnic
%define usnic_version 1.1.545.8.sles12sp3
%define usnic_release 545.8
%define enic_version 2.3.0.44

%global debug_package %{nil}

Name:           %{package_name}
Summary:        Cisco VIC Ethernet NIC drivers
Source0:        usnic_verbs-%{usnic_version}.src.tar.gz
Source1:        cisco-enic-%{enic_version}.tar.gz
Version:        3.0.44.553.545.8
Release:        3.1
Group:          System Environment/Kernel
License:        GPL-2.0
URL:            http://www.cisco.com/
ExclusiveArch:  x86_64
BuildRequires:  %kernel_module_package_buildreqs
BuildRequires:  lsb-release
BuildRequires:  sles-release
BuildRequires:  util-linux
Conflicts:      usnic_verbs
Conflicts:      cisco-enic

%kernel_module_package -p %_sourcedir/preamble

%description
This RPM contains both the Cisco VIC Linux Ethernet driver (enic.ko,
version 2.3.0.44) and the Cisco Userspace NIC (usNIC) Linux
Ethernet driver (usnic_verbs.ko, version 1.1.545.8.sles12sp3).  Some
Linux distros require both kernel modules to be in the same RPM in
order to properly test for symbol compatibility (because
usnic_verbs.ko depends on enic.ko) when installing into post-GA
upgrade kernels.

%prep

#########################################################################

%setup -q -c -T -a 0
# enic setup
tar xf %_sourcedir/cisco-enic-%{enic_version}.tar.gz
echo "enic.ko external" > cisco-enic-%{enic_version}/Module.supported

# usNIC setup
# Note that the usnic_verbs tarball is source0, so rpmbuild
# already untarred it for us.
echo "usnic_verbs.ko external" > usnic_verbs-%{usnic_version}/Module.supported

# Make a copy of the source for each flavor that we need to build
for flavor in %flavors_to_build; do
    rm -rf build-$flavor
    mkdir build-$flavor
    cp -r cisco-enic-%{enic_version} build-$flavor

    # usNIC does not support the SLES 12 SP1/SP2 Xen kernel
    if test "$flavor" != "xen"; then
        cp -r usnic_verbs-%{usnic_version} build-$flavor
    fi
done

#########################################################################

%build
# losetup is in /sbin, which is not in the PATH by default
export PATH=/sbin:$PATH

# Build each flavor
for flavor in %flavors_to_build; do
    pushd build-$flavor

    # enic build
    pushd cisco-enic-%{enic_version}
    enic_build_dir=`pwd`
    make versioncheck
    make -C %{kernel_source $flavor} M=$PWD
    export EXTRA_CFLAGS=
    popd

    # usNIC build
    # usNIC does not support the SLES 12 SP1/SP2 Xen kernel
    if test "$flavor" != "xen"; then
        pushd usnic_verbs-%{usnic_version}
        $PWD/configure %{?config_str} --with-enic=$enic_build_dir --with-release=%{usnic_release}
        make -C %{kernel_source $flavor} M=$PWD
        popd
    fi

    popd
done

#########################################################################

%install
export INSTALL_MOD_PATH=$RPM_BUILD_ROOT
export INSTALL_MOD_DIR=updates
# losetup is in /sbin, which is not in the PATH by default
export PATH=/sbin:$PATH


# Install each flavor
for flavor in %flavors_to_build; do
    pushd build-$flavor

    # enic install
    make -C %{kernel_source $flavor} M=$PWD/cisco-enic-%{enic_version} modules_install

    # usNIC install
    # usNIC does not support the SLES 12 SP1/SP2 Xen kernel
    if test "$flavor" != "xen"; then
        make -C %{kernel_source $flavor} M=$PWD/usnic_verbs-%{usnic_version} modules_install
    fi

    popd
done

#########################################################################

%clean
rm -rf %{buildroot}

#########################################################################

%changelog
* Tue Apr 25 2017 Jeff Squyres <jsquyres@cisco.com>
- Creation of specfile for single RPM containing both enic.ko and
  usnic_verbs.ko.  Heavily influenced by existing enic and usnic_verbs
  spec files.

- Make special enic+usnic combo RPM for SLES 12 SP1/SP2

* Thu May  2 2013 Reese Faucette <rfaucett@cisco.com>
- Adappted to USNIC builds, allow for null kmod_rel

* Wed May 18 2011 Vasanthy Kolluri <vkolluri@cisco.com>
- Added support for symbol greylists

* Wed Mar 3 2010 Jon Masters <jcm@redhat.com>
- Updated some of the documentation.

* Sun Aug 9 2009 Jiri Olsa <jolsa@redhat.com>
- Initial tmpl package.
